#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Author: Chris Lumens <clumens@redhat.com>

from autotest_lib.client.bin import utils
from autotest_lib.client.common_lib import error
from autoqa.test import AutoQATest
from autoqa.repoinfo import repoinfo
from autoqa.decorators import ExceptionCatcher
import logging
import os
import sys

class anaconda_storage(AutoQATest):
    version = 1


    @ExceptionCatcher()
    def setup(self, **kwargs):
        # Install packages that provide commands used by runtest.py
        cmd = "yum -y install livecd-tools qemu-kvm genisoimage parted " \
              "dosfstools qemu-img pyparted"
        retval = utils.system(cmd)
        assert retval == 0


    @ExceptionCatcher()
    def initialize(self, config, **kwargs):
        super(self.__class__, self).initialize(config)


    def process_exception(self, exc):
        self.framework.stopReportServer()
        AutoQATest.process_exception(self, exc)


    @ExceptionCatcher()
    def run_once(self, event, *args, **kwargs):
        # We need to get the directory containing framework/ into the
        # PYTHONPATH for the next import to work.
        sys.path.append(self.bindir)
        from framework import StorageTestFramework

        # Build arguments for the test script (runtest.py)
        repos = []
        if event == "post-koji-build":
            nvr = kwargs.get('nvr','')
            kojitag = kwargs.get('kojitag','')
            name = kwargs.get('name','')
            assert nvr.startswith("anaconda"), "This test is only applies to anaconda (not '%s')" % nvr

            # Add requested repo
            repo = repoinfo.getrepo_by_tag(kojitag)
            assert repo, "Unable to find repository configuration for tag '%s'" % kojitag
            repos.append(repo['url'])
            # Add applicable parent repos
            for parent in repo.get('parents',[]):
                try:
                    prepo = repoinfo.getrepo(parent)
                except:
                    continue
                else:
                    repos.append(prepo['url'])

        elif event == "post-tree-compose":
            repos = [kwargs.get("baseurl")]
        else:
            raise error.TestFail("Unsupported event: %s" % event)

        logging.basicConfig(level=logging.DEBUG)

        self.framework = StorageTestFramework(livecddir=self.tmpdir,
                                              tmpdir=self.tmpdir,
                                              basedir=self.bindir+"/framework",
                                              resultsdir=self.resultsdir,
                                              repos=repos)
        self.framework.setupDirs()
        self.framework.startReportServer()
        self.framework.run()
        self.framework.stopReportServer()

        # check command return code
        if os.path.exists("%s/PASSED" % self.resultsdir):
            self.detail.result = 'PASSED'
        else:
            self.detail.result = 'FAILED'

        if event == "post-koji-build":
            self.post_results(self.detail, optin = {'pkg': name, 'kojitag': kojitag})
        elif event == "post-tree-compose":
            reponame = kwargs.get('name','')
            if reponame in repoinfo.repos():
                kojitag = repoinfo.get(reponame, 'tag')
                self.post_results(self.detail, optin = {'pkg': "anaconda", 'kojitag': kojitag})
