#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

import os, sys

from cases import *

class NoSwapLVMRunner(BaseRunner):
    def writeKickstart(self):
        fo = open("/tmp/kickstart.ks", "w")
        fo.write("clearpart --all\n")
        fo.write("zerombr\n")
        fo.write("part /boot --asprimary --fstype=ext4 --size=500\n")
        fo.write("part pv.01 --grow --maxsize=2048 --size=1024\n")
        fo.write("part pv.02 --grow --maxsize=2048 --size=1024\n")
        fo.write("volgroup SNAKEVG --pesize=32768 pv.01 pv.02\n")
        fo.write("logvol / --fstype=ext4 --grow --size=2048 --name=SNAKEROOT --vgname=SNAKEVG\n")
        fo.close()

class NoSwapLVMTestCase(BaseTestCase):
    def test_boot(self):
        self.default_test_boot()

    def test_lvm(self):
        # Check that two PVs were created and that they have the same size.
        pvs = self.getDevs(self.state, format="lvmpv")
        self.assert_(len(pvs) == 2,
                     "Partitioning did not create exactly two PVs.")
        self.assert_(pvs[0]["length"] == pvs[1]["length"],
                     "Partitioning did not create equal sized PVs.")

        # Check that a single VG was created and that it is composed of two
        # devices.
        vg = self.single(self.getDevs(self.state, type="lvmvg"))
        self.failIf(not vg,
                    "Partitioning did not create a volume group.")
        self.assert_(len(vg["parents"]) == 2,
                     "Volume group is not composed of exactly two devices.")

    def test_root(self):
        rootDev = self.single(self.getDevs(self.state, mountpoint="/"))
        self.failIf(not rootDev,
                    "autopart did not create /.")

        # Check the fs type and underlying device of /.
        self.assert_(rootDev["format"]["type"] == "ext4",
                     "Type of / is not ext4.")
        self.assert_(rootDev["type"] == "lvmlv",
                     "/ was not created on a logical volume.")

    def test_swap(self):
        self.failIf(len(self.getDevs(self.state, format="swap")) > 0,
                    "Partitioning created a swap when it shouldn't have.")
